@@ -5,6 +5,7 @@ declare(strict_types=1);
 namespace Brick\VarExporter\Internal\ObjectExporter;
 
 use Brick\VarExporter\Internal\ObjectExporter;
+use Override;
 
 /**
  * Handles any class through direct property access and bound closures.
@@ -14,21 +15,18 @@ use Brick\VarExporter\Internal\ObjectExporter;
  *
  * @internal This class is for internal use, and not part of the public API. It may change at any time without warning.
  */
-class AnyObjectExporter extends ObjectExporter
+final class AnyObjectExporter extends ObjectExporter
 {
-    /**
-     * {@inheritDoc}
-     */
+    #[Override]
     public function supports(\ReflectionObject $reflectionObject) : bool
     {
         return true;
     }
 
     /**
-     * {@inheritDoc}
-     *
      * @psalm-suppress MixedAssignment
      */
+    #[Override]
     public function export(object $object, \ReflectionObject $reflectionObject, array $path, array $parentIds) : array
     {
         $lines = $this->getCreateObjectCode($reflectionObject);
@@ -156,9 +154,6 @@ class AnyObjectExporter extends ObjectExporter
     /**
      * Returns the key of the given property in the object-to-array cast.
      *
-     * @param \ReflectionProperty $property
-     *
-     * @return string
      */
     private function getPropertyKey(\ReflectionProperty $property) : string
     {
@@ -175,11 +170,6 @@ class AnyObjectExporter extends ObjectExporter
         return $name;
     }
 
-    /**
-     * @param string $var
-     *
-     * @return string
-     */
     private function escapePropName(string $var) : string
     {
         if (preg_match('/^[a-zA-Z_][a-zA-Z0-9_]*$/', $var) === 1) {
