@@ -5,26 +5,23 @@ declare(strict_types=1);
 namespace Brick\VarExporter\Internal\ObjectExporter;
 
 use Brick\VarExporter\Internal\ObjectExporter;
+use Override;
 
 /**
  * Handles instances of classes with __serialize() and __unserialize() methods.
  *
  * @internal This class is for internal use, and not part of the public API. It may change at any time without warning.
  */
-class SerializeExporter extends ObjectExporter
+final class SerializeExporter extends ObjectExporter
 {
-    /**
-     * {@inheritDoc}
-     */
+    #[Override]
     public function supports(\ReflectionObject $reflectionObject) : bool
     {
         return $reflectionObject->hasMethod('__serialize')
             && $reflectionObject->hasMethod('__unserialize');
     }
 
-    /**
-     * {@inheritDoc}
-     */
+    #[Override]
     public function export(object $object, \ReflectionObject $reflectionObject, array $path, array $parentIds) : array
     {
         $lines = $this->getCreateObjectCode($reflectionObject);
