@@ -54,11 +54,6 @@ final class VarExporter
      */
     public const INLINE_SCALAR_LIST = 1 << 7;
 
-    /**
-     * @deprecated Please use INLINE_SCALAR_LIST instead.
-     */
-    public const INLINE_NUMERIC_SCALAR_ARRAY = self::INLINE_SCALAR_LIST;
-
     /**
      * Export static vars defined via `use` as variables.
      */
@@ -85,11 +80,9 @@ final class VarExporter
      *                         Combine multiple options with a bitwise OR `|` operator.
      * @param int $indentLevel The base output indentation level.
      *
-     * @return string
-     *
      * @throws ExportException
      */
-    public static function export($var, int $options = 0, int $indentLevel = 0) : string
+    public static function export(mixed $var, int $options = 0, int $indentLevel = 0) : string
     {
         $exporter = new GenericExporter($options, $indentLevel);
         $lines = $exporter->export($var, [], []);
@@ -106,7 +99,7 @@ final class VarExporter
             $export = $firstLine . PHP_EOL . implode(PHP_EOL, $lines);
         }
 
-        if ($options & self::ADD_RETURN) {
+        if (($options & self::ADD_RETURN) !== 0) {
             return 'return ' . $export . ';' . PHP_EOL;
         }
 
