@@ -16,10 +16,8 @@ abstract class AbstractTestCase extends TestCase
      * @param string $expected The expected export() output.
      * @param mixed  $var      The variable to export.
      * @param int    $options  The options to pass to export().
-     *
-     * @return void
      */
-    public function assertExportEquals(string $expected, $var, int $options = 0) : void
+    public function assertExportEquals(string $expected, mixed $var, int $options = 0) : void
     {
         // test the string output of export()
 
@@ -45,10 +43,8 @@ abstract class AbstractTestCase extends TestCase
         // if the exported value is a closure with no parameters, test that the exported closure returns the same
         // value as the original closure
 
-        if ($var instanceof \Closure) {
-            if ((new \ReflectionFunction($var))->getNumberOfRequiredParameters() === 0) {
-                $this->assertSame($var(), ($exportedVar()), 'The exported closure does not return the same value as the original closure.');
-            }
+        if ($var instanceof \Closure && (new \ReflectionFunction($var))->getNumberOfRequiredParameters() === 0) {
+            $this->assertSame($var(), ($exportedVar()), 'The exported closure does not return the same value as the original closure.');
         }
     }
 
@@ -58,10 +54,8 @@ abstract class AbstractTestCase extends TestCase
      * @param string $expectedMessage The expected exception message. Can use '*' as a placeholder.
      * @param mixed  $var             The variable to export.
      * @param int    $options         The options to pass to export().
-     *
-     * @return void
      */
-    public function assertExportThrows(string $expectedMessage, $var, int $options = 0) : void
+    public function assertExportThrows(string $expectedMessage, mixed $var, int $options = 0) : void
     {
         $expectedMessageRegExp = '/' . implode('.*', array_map(fn(string $str) => preg_quote($str, '/'), explode('*', $expectedMessage))) . '/';
 
