@@ -8,6 +8,7 @@ use Brick\VarExporter\ExportException;
 use Brick\VarExporter\Tests\Classes\PublicPropertiesOnly;
 use Brick\VarExporter\Tests\Classes\SetState;
 use Brick\VarExporter\VarExporter;
+use PHPUnit\Framework\Attributes\DataProvider;
 
 class VarExporterTest extends AbstractTestCase
 {
@@ -49,107 +50,55 @@ class VarExporterTest extends AbstractTestCase
             'aCustomObject' => $myObject
         ];
 
-        if (PHP_VERSION_ID >= 80100) {
             $expected = <<<'PHP'
-[
-    'aString' => 'Hello',
-    'aTrue' => true,
-    'aFalse' => false,
-    'aNull' => null,
-    'aFloat' => 0.75,
-    'anInt' => 123,
-    'aNumericArray' => [
-        'a',
-        'b',
-        null,
-        [
-            'c' => 'd'
-        ]
-    ],
-    'anAssociativeArray' => [
-        'a' => 'b',
-        'c' => [
-            'd' => 'e',
-            'f' => [
-                'g' => [
-                    []
+                [
+                    'aString' => 'Hello',
+                    'aTrue' => true,
+                    'aFalse' => false,
+                    'aNull' => null,
+                    'aFloat' => 0.75,
+                    'anInt' => 123,
+                    'aNumericArray' => [
+                        'a',
+                        'b',
+                        null,
+                        [
+                            'c' => 'd'
+                        ]
+                    ],
+                    'anAssociativeArray' => [
+                        'a' => 'b',
+                        'c' => [
+                            'd' => 'e',
+                            'f' => [
+                                'g' => [
+                                    []
+                                ]
+                            ]
+                        ]
+                    ],
+                    'anObject' => (object) [
+                        'type' => 'string',
+                        '$ref' => '#/components/schema/User',
+                        'items' => (object) [
+                            'foo' => 'bar',
+                            'empty' => (object) []
+                        ]
+                    ],
+                    'aCustomObject' => (static function() {
+                        $object = new \Brick\VarExporter\Tests\Classes\PublicPropertiesOnly;
+
+                        $object->foo = 'hello';
+                        $object->bar = \Brick\VarExporter\Tests\Classes\SetState::__set_state([
+                            'foo' => 'SetState.foo',
+                            'bar' => 'SetState.bar',
+                            'baz' => 'defaultValue'
+                        ]);
+
+                        return $object;
+                    })()
                 ]
-            ]
-        ]
-    ],
-    'anObject' => (object) [
-        'type' => 'string',
-        '$ref' => '#/components/schema/User',
-        'items' => (object) [
-            'foo' => 'bar',
-            'empty' => (object) []
-        ]
-    ],
-    'aCustomObject' => (static function() {
-        $object = new \Brick\VarExporter\Tests\Classes\PublicPropertiesOnly;
-
-        $object->foo = 'hello';
-        $object->bar = \Brick\VarExporter\Tests\Classes\SetState::__set_state([
-            'foo' => 'SetState.foo',
-            'bar' => 'SetState.bar',
-            'baz' => 'defaultValue'
-        ]);
-
-        return $object;
-    })()
-]
-PHP;
-        } else {
-            $expected = <<<'PHP'
-[
-    'aString' => 'Hello',
-    'aTrue' => true,
-    'aFalse' => false,
-    'aNull' => null,
-    'aFloat' => 0.75,
-    'anInt' => 123,
-    'aNumericArray' => [
-        'a',
-        'b',
-        null,
-        [
-            'c' => 'd'
-        ]
-    ],
-    'anAssociativeArray' => [
-        'a' => 'b',
-        'c' => [
-            'd' => 'e',
-            'f' => [
-                'g' => [
-                    []
-                ]
-            ]
-        ]
-    ],
-    'anObject' => (object) [
-        'type' => 'string',
-        '$ref' => '#/components/schema/User',
-        'items' => (object) [
-            'foo' => 'bar',
-            'empty' => (object) []
-        ]
-    ],
-    'aCustomObject' => (static function() {
-        $object = new \Brick\VarExporter\Tests\Classes\PublicPropertiesOnly;
-
-        $object->foo = 'hello';
-        $object->bar = \Brick\VarExporter\Tests\Classes\SetState::__set_state([
-            'baz' => 'defaultValue',
-            'foo' => 'SetState.foo',
-            'bar' => 'SetState.bar'
-        ]);
-
-        return $object;
-    })()
-]
-PHP;
-        }
+                PHP;
 
         $this->assertExportEquals($expected, $var);
     }
@@ -160,16 +109,16 @@ PHP;
         $object->{'$ref'} = '#/components/schemas/User';
 
         $expected = <<<'PHP'
-(static function() {
-    $object = new \Brick\VarExporter\Tests\Classes\PublicPropertiesOnly;
+            (static function() {
+                $object = new \Brick\VarExporter\Tests\Classes\PublicPropertiesOnly;
 
-    $object->foo = null;
-    $object->bar = null;
-    $object->{'$ref'} = '#/components/schemas/User';
+                $object->foo = null;
+                $object->bar = null;
+                $object->{'$ref'} = '#/components/schemas/User';
 
-    return $object;
-})()
-PHP;
+                return $object;
+            })()
+            PHP;
 
         $this->assertExportEquals($expected, $object);
     }
@@ -190,8 +139,8 @@ PHP;
         ];
 
         $expected = <<<'PHP'
-['one' => ['hello', 'world', 123, true, false, null, 7.5], 'two' => ['hello', 'world', [1 => 'one', 2 => 'two', 3 => 'three']]]
-PHP;
+            ['one' => ['hello', 'world', 123, true, false, null, 7.5], 'two' => ['hello', 'world', [1 => 'one', 2 => 'two', 3 => 'three']]]
+            PHP;
 
         $this->assertExportEquals($expected, $var, VarExporter::INLINE_ARRAY);
     }
@@ -204,15 +153,15 @@ PHP;
         ];
 
         $expected = <<<'PHP'
-[
-    'one' => ['hello', 'world', 123, true, false, null, 7.5],
-    'two' => [
-        'hello',
-        'world',
-        ['one', 'two', 'three']
-    ]
-]
-PHP;
+            [
+                'one' => ['hello', 'world', 123, true, false, null, 7.5],
+                'two' => [
+                    'hello',
+                    'world',
+                    ['one', 'two', 'three']
+                ]
+            ]
+            PHP;
 
         $this->assertExportEquals($expected, $var, VarExporter::INLINE_SCALAR_LIST);
     }
@@ -225,15 +174,15 @@ PHP;
         ];
 
         $expected = <<<'PHP'
-[
-    'one' => ['hello', 'world', 123, true, false, null, 7.5],
-    'two' => [
-        'hello',
-        'world',
-        ['one', 'two', 'three'],
-    ],
-]
-PHP;
+            [
+                'one' => ['hello', 'world', 123, true, false, null, 7.5],
+                'two' => [
+                    'hello',
+                    'world',
+                    ['one', 'two', 'three'],
+                ],
+            ]
+            PHP;
 
         $this->assertExportEquals($expected, $var, VarExporter::INLINE_SCALAR_LIST | VarExporter::TRAILING_COMMA_IN_ARRAY);
     }
@@ -246,12 +195,12 @@ PHP;
         $var = \DateTime::createFromFormat($format, '2020-03-09 18:51:23.000000', $timezone);
 
         $expected = <<<'PHP'
-\DateTime::__set_state([
-    'date' => '2020-03-09 18:51:23.000000',
-    'timezone_type' => 3,
-    'timezone' => 'Europe/Berlin'
-])
-PHP;
+            \DateTime::__set_state([
+                'date' => '2020-03-09 18:51:23.000000',
+                'timezone_type' => 3,
+                'timezone' => 'Europe/Berlin'
+            ])
+            PHP;
 
         $this->assertExportEquals($expected, $var);
     }
@@ -264,12 +213,12 @@ PHP;
         $var = \DateTimeImmutable::createFromFormat($format, '2020-03-10 17:06:19.000000', $timezone);
 
         $expected = <<<'PHP'
-\DateTimeImmutable::__set_state([
-    'date' => '2020-03-10 17:06:19.000000',
-    'timezone_type' => 3,
-    'timezone' => 'Europe/Berlin'
-])
-PHP;
+            \DateTimeImmutable::__set_state([
+                'date' => '2020-03-10 17:06:19.000000',
+                'timezone_type' => 3,
+                'timezone' => 'Europe/Berlin'
+            ])
+            PHP;
 
         $this->assertExportEquals($expected, $var);
     }
@@ -313,25 +262,25 @@ PHP;
         ];
 
         $expected = <<<'PHP'
-[
-    'x' => (static function() {
-        $object = new \Brick\VarExporter\Tests\Classes\PublicPropertiesOnly;
+            [
+                'x' => (static function() {
+                    $object = new \Brick\VarExporter\Tests\Classes\PublicPropertiesOnly;
 
-        $object->foo = 'Foo';
-        $object->bar = 'Bar';
+                    $object->foo = 'Foo';
+                    $object->bar = 'Bar';
 
-        return $object;
-    })(),
-    'y' => (static function() {
-        $object = new \Brick\VarExporter\Tests\Classes\PublicPropertiesOnly;
+                    return $object;
+                })(),
+                'y' => (static function() {
+                    $object = new \Brick\VarExporter\Tests\Classes\PublicPropertiesOnly;
 
-        $object->foo = 'Foo';
-        $object->bar = 'Bar';
+                    $object->foo = 'Foo';
+                    $object->bar = 'Bar';
 
-        return $object;
-    })()
-]
-PHP;
+                    return $object;
+                })()
+            ]
+            PHP;
 
         $this->assertExportEquals($expected, $var);
     }
@@ -354,19 +303,15 @@ PHP;
         ]);
     }
 
-    /**
-     * @dataProvider providerExportIndented
-     *
-     * @param mixed $var
-     */
-    public function testExportIndented($var, string $expected, int $options): void
+    #[DataProvider('providerExportIndented')]
+    public function testExportIndented(mixed $var, string $expected, int $options): void
     {
         $template = <<<'TPL'
-public function foo()
-{
-    $data = {{exported}};
-}
-TPL;
+            public function foo()
+            {
+                $data = {{exported}};
+            }
+            TPL;
 
         $exported = VarExporter::export($var, $options, 1);
         $result = str_replace('{{exported}}', $exported, $template);
@@ -374,32 +319,32 @@ TPL;
         $this->assertEquals($expected, $result);
     }
 
-    public function providerExportIndented(): iterable
+    public static function providerExportIndented(): iterable
     {
         // Array
         $var = ['one' => ['hello', true], 'two' => 2];
         $expected = <<<'PHP'
-public function foo()
-{
-    $data = [
-        'one' => [
-            'hello',
-            true
-        ],
-        'two' => 2
-    ];
-}
-PHP;
+            public function foo()
+            {
+                $data = [
+                    'one' => [
+                        'hello',
+                        true
+                    ],
+                    'two' => 2
+                ];
+            }
+            PHP;
         yield [$var, $expected, 0];
 
         // Null
         $var = null;
         $expected = <<<'PHP'
-public function foo()
-{
-    $data = null;
-}
-PHP;
+            public function foo()
+            {
+                $data = null;
+            }
+            PHP;
         yield [$var, $expected, 0];
 
         // Closure
@@ -407,13 +352,13 @@ PHP;
             return 'Hello, world!';
         };
         $expected = <<<'PHP'
-public function foo()
-{
-    $data = function () {
-        return 'Hello, world!';
-    };
-}
-PHP;
+            public function foo()
+            {
+                $data = function () {
+                    return 'Hello, world!';
+                };
+            }
+            PHP;
         yield [$var, $expected, 0];
 
         $foo = 'bar';
@@ -425,17 +370,17 @@ PHP;
         };
 
         $expected = <<<'PHP'
-public function foo()
-{
-    $data = function () {
-        $sub = function () {
-            $foo = 'bar';
-            return $foo;
-        };
-        return $sub();
-    };
-}
-PHP;
+            public function foo()
+            {
+                $data = function () {
+                    $sub = function () {
+                        $foo = 'bar';
+                        return $foo;
+                    };
+                    return $sub();
+                };
+            }
+            PHP;
         yield [$var, $expected, VarExporter::CLOSURE_SNAPSHOT_USES];
 
         $var = function () {
@@ -443,36 +388,36 @@ PHP;
 World!';
 
             $b = <<<TXT
-Hello,
-world!
-TXT;
+            Hello,
+            world!
+            TXT;
 
             $c = <<<'TXT'
-Hello,
-world!
-TXT;
+            Hello,
+            world!
+            TXT;
 
             return $a . $b . $c;
         };
 
         $expected = <<<'PHP'
-public function foo()
-{
-    $data = function () {
-        $a = 'Hello,
-World!';
-        $b = <<<TXT
-        Hello,
-        world!
-        TXT;
-        $c = <<<'TXT'
-        Hello,
-        world!
-        TXT;
-        return $a . $b . $c;
-    };
-}
-PHP;
+            public function foo()
+            {
+                $data = function () {
+                    $a = 'Hello,
+            World!';
+                    $b = <<<TXT
+                    Hello,
+                    world!
+                    TXT;
+                    $c = <<<'TXT'
+                    Hello,
+                    world!
+                    TXT;
+                    return $a . $b . $c;
+                };
+            }
+            PHP;
 
         yield [$var, $expected, 0];
     }
